<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package web2feel
 * @since web2feel 1.0
 */

if ( ! function_exists( 'web2feel_content_nav' ) ):
/**
 * Display navigation to next/previous pages when applicable
 *
 * @since web2feel 1.0
 */
function web2feel_content_nav( $nav_id ) {
	global $wp_query;

	$nav_class = 'site-navigation paging-navigation';
	if ( is_single() )
		$nav_class = 'site-navigation post-navigation';

	?>
	<nav role="navigation" id="<?php echo $nav_id; ?>" class="<?php echo $nav_class; ?>">
		<h1 class="assistive-text"><?php _e( 'منوی پست', 'web2feel' ); ?></h1>

	<?php if ( is_single() ) : // navigation links for single posts ?>

		<?php previous_post_link( '<div class="nav-previous">%link</div>', '<span class="meta-nav">' . _x( '&larr;', 'لینک پست قبلی', 'web2feel' ) . '</span> %title' ); ?>
		<?php next_post_link( '<div class="nav-next">%link</div>', '%title <span class="meta-nav">' . _x( '&rarr;', 'لینک پست بعدی', 'web2feel' ) . '</span>' ); ?>

	<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>

		<?php if ( get_next_posts_link() ) : ?>
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> پست های قدیمی تر', 'web2feel' ) ); ?></div>
		<?php endif; ?>

		<?php if ( get_previous_posts_link() ) : ?>
		<div class="nav-next"><?php previous_posts_link( __( 'پست های جدید تر <span class="meta-nav">&rarr;</span>', 'web2feel' ) ); ?></div>
		<?php endif; ?>

	<?php endif; ?>

	</nav><!-- #<?php echo $nav_id; ?> -->
	<?php
}
endif; // web2feel_content_nav

if ( ! function_exists( 'web2feel_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since web2feel 1.0
 */
function web2feel_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	
	
	
<li class="post pingback">
<p><?php _e( 'پینگ بک:', 'web2feel' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(ویرایش)', 'web2feel' ), ' ' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class('cf'); ?> id="li-comment-<?php comment_ID(); ?>">
	<article id="comment-<?php comment_ID(); ?>" class="comment">
	<footer class="cf  comfooter">
	
<div align="center">
<div class="comment-block" >
<table border="0" width="100%" cellspacing="0" cellpadding="0" >
<tr>
<td width="150" align="center"><div class="comment-avatar3"><div class="comment-avatar2"><?php echo get_avatar( $comment, 64 ); ?></div></div></td>
<td valign="top">
<div class="comment-name" align="right"><?php printf( __( '%s <span class="says">میگه:</span>', 'web2feel' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>


					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>"><time pubdate datetime="<?php comment_time( 'c' ); ?>">
					<?php
						/* translators: 1: date, 2: time */
						printf( __( '%1$s در %2$s', 'web2feel' ), get_comment_date(), get_comment_time() ); ?>
					</time></a>
					<?php edit_comment_link( __( '(ویرایش)', 'web2feel' ), ' ' );
					?>

</div>
<div class="comment-khat"></div>
<div class="comment-text" align="right">
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em><?php _e( 'دیدگاه شما در دست بررسی مدیریت است.', 'web2feel' ); ?></em>
					<br />
				<?php endif; ?>
<?php comment_text(); ?>


<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
</div>
</td>
</tr>
</table>
</div>
</div>
<br>
	</footer>
	</article>
	</li>

	<?php
			break;
	endswitch;
}
endif; // ends check for web2feel_comment()

if ( ! function_exists( 'web2feel_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since web2feel 1.0
 */
function web2feel_posted_on() {
	printf( __( 'ارسال شده در <a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s" pubdate>%4$s</time></a><span class="byline"> توسط <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'web2feel' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'نمایش همه ی پست های %s', 'web2feel' ), get_the_author() ) ),
		esc_html( get_the_author() )
	);
}
endif;

